---
title: Needs-based communication
description: How to connect with others through shared human needs
---

Needs-based communication (usually called non-violent communication or NVC™) is a way of understanding yourself and others with a unique insight: everyone has their own personal reactions to the world, but people have the same basic needs. We recognize those needs in other people, and that common connection can allow us to communicate clearly when there is conflict.

**Needs** are universal to humanity. They are common drives that we all experience, and this universality makes them perfect for connecting with each other. Some broad categories of needs are the needs for: connection, physical well-being, honesty, play, peace, autonomy, and meaning. Needs can also be specific: a need for clarity, nurturing, integrity, trust, space, etc. Needs are abstract, not connected to people or actions. For example, peace is a need, muting TV commercials is not. Here is [a partial list of needs](https://www.cnvc.org/training/resource/needs-inventory) from the Center for Non-Violent Communication (CNVC).

Everything _anyone_ does is an attempt to meet a need. None of these universal needs is wrong or inherently harmful, although sometimes the strategies we use can be.

**Conflict** happens when our needs aren't met. We get stuck in conflict when we mix up needs and strategies. Needs never conflict with each other, only strategies do.

When we experience conflict or negative feelings, that indicates that there is an unmet need. In an attempt to end a conflict, we often settle on unsatisfying resolutions:

1. We suppress the need and move on, painfully leaving the problem unaddressed.
2. We come to an uneasy agreement about who is the winner and who is the loser, and the loser gives up on meeting their need. The immediate conflict is over, but the problem is not really resolved.
3. We escalate, expanding the conflict in an attempt to win, at the other's expense if necessary.

These resolutions can happen despite our best intentions, as a result of not understanding what's happening as we fight. A very common mistake is to confuse needs and strategies.

**Strategies** are things we do to meet our needs. In contrast to needs, which are abstract and universal, strategies are personal, specific, and widely varied.

For example, consider the need for self-expression. There are as many strategies as there are people and situations: singing, writing, talking, composing, dressing a certain way... and on and on.

Jumping into a conflict strategy-first is bound to cause problems if that strategy doesn't meet others' needs as well as your own. The way past conflict is for everyone involved to understand each others' needs, and _then_ work together to find a strategy to meet those needs.

So, **how do you figure out your own needs?**

Negative feelings are a sign that you have an unmet need. Unfortunately, most of us have learned to bundle in certain judgments and name them as feelings. For example, I might think I am feeling _abandoned_, but really this is a feeling of disconnectedness, vulnerability, loneliness, or something else, combined with a judgment that someone else has made me feel that way.

The truth is that the same situation can affect people very differently. This means that feelings must come from a person's own response to things. In order to see your feelings clearly, it is important to take ownership of them as _your_ feelings rather than something caused by the world around you. I have found this to be very challenging, but also incredibly rewarding.

Once you have an honest name for what you are feeling, think about what need sparked the feeling.

There is a (kind of clunky) formula for requesting help meeting a need without tacking on strategies, demands, judgments, or other baggage. As the exercise becomes more habitual, you won't need the formula, and can accomplish the same thing more naturally.

Here it is:

> When _[observation]_, I felt _[feeling]_ because I was having a need for _[need]_. (possibly also a request:) Are you willing to _[action]_?

In the spirit of communicating without judgments, the observation should be strictly focused on facts, with no mind-reading or attribution at all. Sharing your feelings in addition to the need can help the other person recognize the need and how it affects you. If the other person understands the need, you can also make a request for some specific action to help meet your need.

It is very important that the action you request be feasible, concrete, and specific. Asking someone to change their behavior forever, think a certain way, etc is too much. The request should also really, truly be a request and not a demand. A "No!" should be as welcome as a "Yes!" because the goal is to find a strategy that meets your needs _and_ theirs.

There is a (similarly clunky) pattern for discovering someone else's needs. As you listen to them, you will probably get an idea for how they feel, and you may be able to guess what need they are experiencing. You can ask:

> When you _[observation]_ do you feel _[feeling]_ because you are having a need for _[need]_? (possibly also:) Right now, would you like me to _[action]_?

Like the other formula, this is just a beginning point, almost too rough to use except for training your responses and replacing old communication habits.

These are two sides of the same coin, a pattern that draws a line from the stimulus, some observation, through the needs, towards a solution. Even if you guess wrong, just focusing on someone's feelings and needs demonstrates that you are really interested in their problem.

Even without explicitly using this pattern (observation ➔ feeling ➔ need ➔ request), just by thinking about needs (your own and others') you can untangle conflict and see other people with much more empathy. Maybe that reckless driver is having a need for excitement and power, and zipping around you was the best strategy they could come up with. Just seeing past the image of others as enemies or obstacles can make the world much less hostile, by revealing them to be real humans, people you might be able to connect with. This way of thinking can also be a path to growth as you take ownership of your feelings and see your needs clearly.

Some resources for exploring these ideas more:

- [The Right Words and Beyond](http://www.therightword.info/)
- [Nonviolent Communication: A Language of Life](https://amzn.to/44cpIsV), ISBN 189200528X
- [The Center for Nonviolent Communication](https://www.cnvc.org/)
